@@ -7,9 +7,13 @@ from typing import Generic, List, Optional
 
 from grpc_requests.aio import AsyncClient
 
-from apibara.indexer.handler import (BlockHandler, MessageHandler,
-                                     NewEventsHandler, ReorgHandler,
-                                     UserContext)
+from apibara.indexer.handler import (
+    BlockHandler,
+    MessageHandler,
+    NewEventsHandler,
+    ReorgHandler,
+    UserContext,
+)
 from apibara.indexer.storage import IndexerStorage
 from apibara.logging import logger
 from apibara.model import BlockHeader, EventFilter, NewBlock, NewEvents
@@ -154,8 +158,12 @@ class IndexerRunner(Generic[UserContext]):
         self._indexer_storage.drop_database()
 
     def _write_initial_state(self):
+        index_from_block = self._indexer_config.get("index_from_block")
+        if index_from_block is None:
+            index_from_block = 0
+
         self._indexer_storage.initialize(
-            self._indexer_config["index_from_block"], self._indexer_config["filters"]
+            index_from_block, self._indexer_config["filters"]
         )
 
     async def _do_run(self):
